==> whmcs-8.6.2-release.1.zip: modules/gateways/tco/lib/index.php <==
<?php //ICB0 72:0 81:1044                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.6.2 (8.6.2-release.1)                                      *
// * BuildId:b8a9b70.304                                                  *
// * Build Date:14 Jun 2023                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPooaW1leYtbSXHSLE2opMMaS6iXgRi32TC8PbOzkD7Yr+w+W24DGdhcnRy05/bOjBk4S9lfQ
EwIP2RHjqTXpfTyu0/YQHeGmqdPHECgLxtPPHtji6RvHFN4ZZRCFntQBH210R0DzJMnOpz4TClkY
+2dJYlroolX2MyeiYD2pDkR29hFcjojfGoa4O+pLj63Zi5Eh+IypRRfTNQY7150oNjy3pXmKsoOC
zoD1OPOmYYZlnTSCd20rU2cx7CWsBGy8dJld79J48MUgsdSoEQPzuJN3xITX9aoFMPZj5gCNOm91
UW1RHxHeYECfi5lB9t0zj7BnemKQLcBgxROcDpYRDxgyFJFG3OPUNDvyfjg9prei/NRPEprp/v3N
9P7AUZjCfe27hWfqnEdSCM4i+g9rTyaQA0VJP3v7yUqGiOgXfHCuUmONguv0ir2d34/hcXjMgD3j
zHD4CpVd9KmWv9fwoytvqu6K0KceqnFN8FrCgo/kEcJpS4porYVmIMJkXcgsMfM/oGC4KAsocRX+
8WoXInzlBLb3zvMOmhkQG2pvUGBPaqDn01tm+68mK8+A/EPhb2zTxw/fw1By5MGqBAb9asmB3Kum
ymBlMs5rLLvygocd9mYr433iQTss9TFA/oDhgQ5C5Fr0AOI/ZhV7pIpomYzdilJ1BevaDIIOpZOv
3b1V8a8r1pAFKTxJDRkl5f4as6/a2TW9npqCsgzXMSs6Jv4tEUVypEDqlIs1g/SujL9z3MXmPPzT
DatmrG8X+7ntOeXbCtm7J7FhdVH1pUl7oLu5ohHfGbpmS7W8hRmLN8VL0+ZNQHz+2lkbmDx/lWIj
wvyG8JGDJDB+dQ4eOwYFj8uRVzlS1NCNQKQloehs+IM9jCwbtynI+m===
HR+cP/XwgjKGtYuQdSG/zdY+7X2EriFLFjd4GBN8Vp2gyuAgndgd1y80tXmZw/q/unh53ry9qN0g
sFkZu4IYWlzeewihUOjBq0JEmvj+88C44kAiy5q7DxmC6ntsb/XSFk2Ca/8ksEV9OeSpGdgUiAFk
eiZ/G4ShK4Ho9uwCwBUnHEnkxkt/za33fcVAJAViiLvwLvEoHoPaykzrxL+NkeRRvnnzgdqMbRZy
GjKcQK03uuz/tjyquFNcAOB7Mq8fixq/tgxKCp9RzgHCqXDj88XRGCxC4EoXM/VkE7E9gfpMou52
0bjpUgD8TcbTYsrkftiuAINRS0EPHRkGO73x5Bovt8BiwndAybZsRSF+Os9+XOOmaaksLmB9MRvp
156EYGRrHP6uyqKar87TsavFAWC1EqCwlAjByqQzcrGz8DsIH6hwuFobII+lZCVPlo1Zry42Cjkq
9RN/Pq3fviXJPpyOzfYqhHvJynwdf8aK7/Crdsh0pkVt64nFe5VD9PPraLOsIORBEIRw9PsPoQt/
ppt6dtDKpCGB39X5gZh0M8O4I9ednerR0EXtMd0MhRqIAafOGvCUFbbumjdIzAtREdWWn0/YOQ6P
NnNu6zukpLwonVysP9souI0kzC6pusugYuu82HXKdHpfq3YtlQEFfyjd7Vh9GkONj5jKcGfmSj/h
Vwy7H/GCl54WV3413CXyAtPkQfmN4848ifQhZ68itKArittRm/9FMvuVrCiHlrlS0vFOV8MJ/RuO
jgyxMMtPNBwQXu3Txo6J5tD6jgPjxa5Ip/aImNVfLkdfaUjQebBVyraFdUPU30JY2lV4xn43jjgv
UmXr3veupjg+/CAM7NyoMN4mw5EmK6Qegu1ZWRuSaflP1hN7qjaB

==> whmcs-8.10.0-release.1.zip: modules/gateways/tco/lib/index.php <==
<?php //ICB0 72:0 81:1044                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.10.0 (8.10.0-release.1)                                    *
// * BuildId:dc9095d.372                                                  *
// * Build Date:23 Apr 2024                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPyeW8x913vY5R9EsaOZa8PKQPayFfJY6dep8KKv5ELHa9HP13UhH/x47hZ8D0JT5cZvIc+Uf
YM89DNNHfs5Bm4TH0iDKRgzR/R99x5X2P7Qvn8BNHlnVp1xMyRk20ndDuVnjRFDRfMta5p8CHCLL
DmytyTG8WvKzhVRcrkfopQ6FJnH82l5XwQnZovWo6ZExlP1mDofdomjhSuH6hYyK9yrXDfpKWID2
SSwmGoAv1pINo/v1ahW+kk722wMD6pvOyk1bHO5/6PfrKMqkzgfRgkA9lWK0PbI3iCDwYuOXe69X
MCaiQwkrrh27/5JewwOqJ6YdSPBN4zygUVzZUxcBC46n07TThtmbntbh7uSJ8KLyrUcTxXdSNkYf
UmAk44WSkYgtq/aKhL/lzVrVO8I4pZPLJvF+VSxcEiva/esca7kvDK+xM6VDNMOEHGRM27rXQIFs
TZXo6Xb2Y5wEz/EhL8L7f5WclUY61gM0N2kIZDwQ26QehsoIDYQzm0pi3uE9IL42L0+eJP7/6aLj
BDogRsti/R+WiViAjDawh8PAnuEJ93FXb0RhK4JyGOBcwS7tyOGhi+EwsIqCycRcJI7t5cPtAuWQ
AXMLf9VuuBdaUd2QLWycHpVSWskwu1FTBfb0IvRkpZ/z/vjoaDpgiglcEqoydn602VurlcXPc0xG
196+Z5glp9KQzDZLzQl/2waGxGrPZXv3Og7K1MZussh8Ng4JdPU0MNM22QdzH5RD/RpUkJQnx3Nh
eKWcUFManIBtYg6ooOMlFz6AOOIaF/EuTOL04NLueN2xwnkF0N0UZJKdMBT/da5jsC4TfST0CCzs
QjuRf/mYPV2NdnVTuGx+nUuaJa0L4AF4IdsnbDebpMKYDxnZkz7LkyW==
HR+cP/OBUlze7kbUyPUrxznRJIKsViVM2aFhHiyZEdVLmkRyCfQgpYwgKJM1EpAGctennFZIbpwl
fN0LROkE7xc0f6Y8x4RdMfub1mQqGd6pElGqApZVyCZST+kU6+Oiux3zThUk4xTvfKWF/W4K+qNl
mkU/OmOLxW0/BrPcfU/C1BhchHfGKIMf9rWUuLWFA/4HrZloAkdu2AjnPre8Za/pI8WSliV8mWL4
+YDA3tdVn8n3sth6pyhORQPXHMO5qQ5C76tU2Jh6s6d/7yftUW+3ido4KQNjDSQD9wAawhQL8MRH
4WzDdtAmyKcRnqrw/P0XgrvMsqh/bh9aVIZFZs8hIMNKGeSUf0bvY+W5kuEEvr9Dd2NqeyD6Cf07
/0VxWZzzqGHYsqXxfPaMfstxZKq357dzpuqAxR11LpH68C5oNZdaqr3FbtiWJBhPLuOSnhk08wQ2
uvNPOe8/6yfrd+8XUHDP/qrUePHAbbiTRzB87GvjSG5/LyPZxeNuQXgsmOnmEUhHlEkvdZHIbJG2
87nx40o6vJDbGHWDE+W93+p3L/rPU+9TyuH7qaHPuxVi0x9pQgJbZhPQzLqYpwiKSiE/Ncp45efJ
HFn2FR3qHfbgUq1uS0O4nuQthY7y4JqIGPS195Npw0QSL3B+z0GalovJJkCQvxq0K4KUdddf8ekE
6PrgodfM6xIiY9ubmxgB9hVnwQihnYlEN9RNn2tOIPnDej3fRAIAPi6rgNlQs4tRkwrXqsr7oiV7
r3rr3PQGZN0oZbYDss8Y0+LEz2xIAfmxgJLAyyRJDevpFSSWAFwsXax1mJkq8PqLOqiplBSpP/LZ
3m2GtLSWolz3YpYu+IbfqpVu/q4z9f4NiFEVSBXp3ATzClUkUesehyxc1G==
